@@ -1,2 +1,5 @@
-vcov.mcmc <- function(object, ...) 
+vcov.mcmc <- 
+function(object, ...) 
+{
     dclone:::vcov.mcmc.list(as.mcmc.list(object), ...)
+}
